sdfgsd sergserg wrote:
Well, it does fail under Suse 9.0.

Please try this patch which prevents from fastcgi being loaded. I don't know what's the C name for fastcgi module. I've assumed that it's fastcgi.c. Please adjust it if it's wrong.


Next if someone could try to investigate why this crash happens that would be great.

Index: lib/ModPerl/TestRun.pm
===================================================================
--- lib/ModPerl/TestRun.pm      (revision 111891)
+++ lib/ModPerl/TestRun.pm      (working copy)
@@ -62,11 +62,13 @@
     return $self;
 }

-# don't inherit LoadModule perl_module from the apache httpd.conf
+# - don't inherit LoadModule perl_module from the apache httpd.conf
+# - loaded fastcgi crashes some mp2 tests
+my %skip = map { ("$_.c" => 1) } qw(mod_perl fastcgi);
 sub should_skip_module {
     my($self, $name) = @_;

-    $name eq 'mod_perl.c' ? 1 : $self->SUPER::should_skip_module($name);
+    exists $skip{$name} ? 1 : $self->SUPER::should_skip_module($name);
 }

 1;

--
__________________________________________________________________
Stas Bekman            JAm_pH ------> Just Another mod_perl Hacker
http://stason.org/     mod_perl Guide ---> http://perl.apache.org
mailto:[EMAIL PROTECTED] http://use.perl.org http://apacheweek.com
http://modperlbook.org http://apache.org   http://ticketmaster.com

--
Report problems: http://perl.apache.org/bugs/
Mail list info: http://perl.apache.org/maillist/modperl.html
List etiquette: http://perl.apache.org/maillist/email-etiquette.html

Reply via email to